@@ -19,7 +19,7 @@ def make_sent_bert_features(text):
     return emb
 
 
-def get_data(save_dataset_fd,documents):
+def get_data(documents):
     """
     returns one big graph with unconnected graphs with the following:
     - x (Tensor, optional) – Node feature matrix with shape [num_nodes, num_node_features]. (default: None)
