@@ -4,9 +4,9 @@ import numpy as np
 import torch
 
 from graphmanagerlib.Graph import Grapher
-from graphmanagerlib.Data_for_gcn import load_predictionData, getDataForUniquePrediction
+from graphmanagerlib.Data_for_gcn import getDataForUniquePrediction
 from torch_geometric.utils.convert import from_networkx
-from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects, GetJsonFromFile,ConvertPredictionToJson
+from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects,ConvertPredictionToJson
 
 def clearOutputFolder(test_output_fd):
     shutil.rmtree(test_output_fd)
