@@ -6,8 +6,8 @@ from graphmanagerlib.GCN import GCN
 import torch.nn.functional as F
 
 
-def CreateTrainAndSaveGCN(train_data,test_data,saved_folder):
-    model = GCN(input_dim=train_data.x.shape[1], chebnet=True)
+def CreateTrainAndSaveGCN(train_data, test_data, saved_folder, nb_classes):
+    model = GCN(input_dim=train_data.x.shape[1], chebnet=True, n_classes=nb_classes)
     device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
     model = model.to(device)
     optimizer = torch.optim.AdamW(
